# Governance Policy

The "Project" is herein defined as the activities related to this specific GitHub repository [`Colorcet`](https://github.com/holoviz/colorcet), within the `HoloViz` GitHub Organization.


This Project adopts the governance specified by all of the numbered sections of [HoloViz/HoloViz - GOVERNANCE.md](https://github.com/holoviz/holoviz/blob/colorcet-gov/doc/governance/project-docs/GOVERNANCE.md).


The Colorcet Project’s equivalently named documents take precedence over any external materials referenced within this linked document above.
